@@ -51,6 +51,7 @@
 		     ("timp.scm" . "v-imp")
 		     ("tlamb.scm" . "v-lamb")
 		     ("thook.scm" . "v-hook")
+		     ("tstar.scm" . "v-star")
 		     ))
 
 (define (last-callg)
@@ -91,8 +92,8 @@
 	 (list "repl" "timp.scm")
 	 (list "repl" "texit.scm")
 	 (list "repl" "s7test.scm")
-	 (list "repl" "tauto.scm")
 	 (list "repl" "thook.scm")
+	 (list "repl" "tauto.scm")
 	 (list "repl" "lt.scm")
 	 (list "repl" "dup.scm")
 	 (list "repl" "tload.scm")
@@ -108,8 +109,9 @@
 	 (list "repl" "tio.scm")
 	 (list "repl" "tmac.scm")
 	 (list "repl" "tclo.scm")
-	 (list "repl" "tlet.scm")
+	 (list "repl" "tstar.scm")
 	 (list "repl" "tcase.scm")
+	 (list "repl" "tlet.scm")
 	 (list "repl" "tfft.scm")
 	 (list "repl" "tmap.scm")
 	 (list "repl" "tshoot.scm")
@@ -121,8 +123,8 @@
 	 (list "repl" "tset.scm")
 	 (list "repl" "tlist.scm")
 	 (list "repl" "tgsl.scm")
-	 (list "repl" "trec.scm")
 	 (reader-cond ((not (provided? 'gmp)) (list "repl" "tari.scm")))
+	 (list "repl" "trec.scm")
 	 (list "repl" "tleft.scm")
 	 (list "repl" "tgc.scm")
 	 (list "repl" "thash.scm")
